BlockHeaderObject

Struct BlockHeaderObject 

pub struct BlockHeaderObject {
Show 15 fields hash: Hash, confirmations: i64, height: Height, version: u32, merkle_root: Root, block_commitments: [u8; 32], final_sapling_root: [u8; 32], sapling_tree_size: u64, time: i64, nonce: [u8; 32], solution: Solution, bits: CompactDifficulty, difficulty: f64, previous_block_hash: Hash, next_block_hash: Option<Hash>,
}
Verbose response to a getblockheader RPC request.

See the notes for the RpcServer::get_block_header method.

Fields

hash: Hash

The hash of the requested block.

confirmations: i64

The number of confirmations of this block in the best chain, or -1 if it is not in the best chain.

height: Height

The height of the requested block.

version: u32

The version field of the requested block.

merkle_root: Root

The merkle root of the requesteed block.

block_commitments: [u8; 32]

The blockcommitments field of the requested block. Its interpretation changes depending on the network and height.

final_sapling_root: [u8; 32]

The root of the Sapling commitment tree after applying this block.

sapling_tree_size: u64

The number of Sapling notes in the Sapling note commitment tree after applying this block. Used by the getblock RPC method.

time: i64

The block time of the requested block header in non-leap seconds since Jan 1 1970 GMT.

nonce: [u8; 32]

The nonce of the requested block header.

solution: Solution

The Equihash solution in the requested block header.

bits: CompactDifficulty

The difficulty threshold of the requested block header displayed in compact form.

difficulty: f64

Floating point number that represents the difficulty limit for this block as a multiple of the minimum difficulty for the network.

previous_block_hash: Hash

The previous block hash of the requested block header.

next_block_hash: Option<Hash>

The next block hash after the requested block header.

Implementations

Source

impl BlockHeaderObject

Auto-generated by derive_getters::Getters.

pub fn hash(&self) -> Hash

The hash of the requested block.

pub fn confirmations(&self) -> i64

The number of confirmations of this block in the best chain, or -1 if it is not in the best chain.

pub fn height(&self) -> Height

The height of the requested block.

pub fn version(&self) -> u32

The version field of the requested block.

pub fn merkle_root(&self) -> Root

The merkle root of the requesteed block.

pub fn block_commitments(&self) -> [u8; 32]

The blockcommitments field of the requested block. Its interpretation changes depending on the network and height.

pub fn final_sapling_root(&self) -> [u8; 32]

The root of the Sapling commitment tree after applying this block.

pub fn sapling_tree_size(&self) -> u64

The number of Sapling notes in the Sapling note commitment tree after applying this block. Used by the getblock RPC method.

pub fn time(&self) -> i64

The block time of the requested block header in non-leap seconds since Jan 1 1970 GMT.

pub fn nonce(&self) -> [u8; 32]

The nonce of the requested block header.

pub fn solution(&self) -> Solution

The Equihash solution in the requested block header.

pub fn bits(&self) -> CompactDifficulty

The difficulty threshold of the requested block header displayed in compact form.

pub fn difficulty(&self) -> f64

Floating point number that represents the difficulty limit for this block as a multiple of the minimum difficulty for the network.

pub fn previous_block_hash(&self) -> Hash

The previous block hash of the requested block header.

pub fn next_block_hash(&self) -> Option<Hash>

The next block hash after the requested block header.

Source

impl BlockHeaderObject

pub fn new( hash: Hash, confirmations: i64, height: Height, version: u32, merkle_root: Root, block_commitments: [u8; 32], final_sapling_root: [u8; 32], sapling_tree_size: u64, time: i64, nonce: [u8; 32], solution: Solution, bits: CompactDifficulty, difficulty: f64, previous_block_hash: Hash, next_block_hash: Option<Hash>, ) -> Self

Constructs a new BlockHeaderObject.