pub struct GetInfoResponse {}Expand description
Response to a getinfo RPC request.
See the notes for the [Rpc::get_info method].
Fields
version: u64The node version
build: StringThe node version build number
subversion: StringThe server sub-version identifier, used as the network protocol user-agent
protocol_version: u32The protocol version
blocks: u32The current number of blocks processed in the server
connections: usizeThe total (inbound and outbound) number of connections the node has
proxy: Option<String>The proxy (if any) used by the server. Currently always None in Zebra.
difficulty: f64The current network difficulty
testnet: boolTrue if the server is running in testnet mode, false otherwise
pay_tx_fee: f64The minimum transaction fee in ZEC/kB
relay_fee: f64The minimum relay fee for non-free transactions in ZEC/kB
errors: StringThe last error or warning message, or “no errors” if there are no errors
errors_timestamp: i64The time of the last error or warning message, or “no errors timestamp” if there are no errors
Implementations
Sourceimpl GetInfoResponse
Auto-generated by derive_getters::Getters.
impl GetInfoResponse
Auto-generated by derive_getters::Getters.
Sourcepub fn raw_version(&self) -> u64
pub fn raw_version(&self) -> u64
The node version
Sourcepub fn subversion(&self) -> &String
pub fn subversion(&self) -> &String
The server sub-version identifier, used as the network protocol user-agent
Sourcepub fn protocol_version(&self) -> u32
pub fn protocol_version(&self) -> u32
The protocol version
Sourcepub fn connections(&self) -> usize
pub fn connections(&self) -> usize
The total (inbound and outbound) number of connections the node has
Sourcepub fn proxy(&self) -> &Option<String>
pub fn proxy(&self) -> &Option<String>
The proxy (if any) used by the server. Currently always None in Zebra.
Sourcepub fn difficulty(&self) -> f64
pub fn difficulty(&self) -> f64
The current network difficulty
Sourcepub fn pay_tx_fee(&self) -> f64
pub fn pay_tx_fee(&self) -> f64
The minimum transaction fee in ZEC/kB
Sourcepub fn errors(&self) -> &String
pub fn errors(&self) -> &String
The last error or warning message, or “no errors” if there are no errors
Sourcepub fn errors_timestamp(&self) -> i64
pub fn errors_timestamp(&self) -> i64
The time of the last error or warning message, or “no errors timestamp” if there are no errors
Sourceimpl GetInfoResponse
impl GetInfoResponse
Sourcepub fn from_parts(
version: u64,
build: String,
subversion: String,
protocol_version: u32,
blocks: u32,
connections: usize,
proxy: Option<String>,
difficulty: f64,
testnet: bool,
pay_tx_fee: f64,
relay_fee: f64,
errors: String,
errors_timestamp: i64,
) -> Self
👎Deprecated: Use GetInfoResponse::new instead
pub fn from_parts( version: u64, build: String, subversion: String, protocol_version: u32, blocks: u32, connections: usize, proxy: Option<String>, difficulty: f64, testnet: bool, pay_tx_fee: f64, relay_fee: f64, errors: String, errors_timestamp: i64, ) -> Self
GetInfoResponse::new insteadConstructs GetInfo from its constituent parts.
Sourcepub fn into_parts(
self,
) -> (u64, String, String, u32, u32, usize, Option<String>, f64, bool, f64, f64, String, i64)
pub fn into_parts( self, ) -> (u64, String, String, u32, u32, usize, Option<String>, f64, bool, f64, f64, String, i64)
Returns the contents of [‘GetInfo’].
Sourcefn version_from_string(build_string: &str) -> Option<u64>
fn version_from_string(build_string: &str) -> Option<u64>
Create the node version number.