pub struct RpcImpl<Mempool, State, ReadState, Tip, AddressBook, BlockVerifierRouter, SyncStatus>where
Mempool: MempoolService,
State: StateService,
ReadState: ReadStateService,
Tip: ChainTip + Clone + Send + Sync + 'static,
AddressBook: AddressBookPeers + Clone + Send + Sync + 'static,
BlockVerifierRouter: BlockVerifierService,
SyncStatus: ChainSyncStatus + Clone + Send + Sync + 'static,{
build_version: String,
user_agent: String,
network: Network,
debug_force_finished_sync: bool,
mempool: Mempool,
state: State,
read_state: ReadState,
latest_chain_tip: Tip,
queue_sender: Sender<UnminedTx>,
address_book: AddressBook,
last_warn_error_log_rx: LoggedLastEvent,
gbt: GetBlockTemplateHandler<BlockVerifierRouter, SyncStatus>,
}Expand description
RPC method implementations.
Fields
build_version: StringZebra’s application version, with build metadata.
user_agent: StringZebra’s RPC user agent.
network: NetworkThe configured network for this RPC service.
debug_force_finished_sync: boolTest-only option that makes Zebra say it is at the chain tip, no matter what the estimated height or local clock is.
mempool: MempoolA handle to the mempool service.
state: StateA handle to the state service.
read_state: ReadStateA handle to the state service.
latest_chain_tip: TipAllows efficient access to the best tip of the blockchain.
queue_sender: Sender<UnminedTx>A sender component of a channel used to send transactions to the mempool queue.
address_book: AddressBookPeer address book.
last_warn_error_log_rx: LoggedLastEventThe last warning or error event logged by the server.
gbt: GetBlockTemplateHandler<BlockVerifierRouter, SyncStatus>Handler for the getblocktemplate RPC.
Implementations
Sourceimpl<Mempool, State, ReadState, Tip, AddressBook, BlockVerifierRouter, SyncStatus> RpcImpl<Mempool, State, ReadState, Tip, AddressBook, BlockVerifierRouter, SyncStatus>where
Mempool: MempoolService,
State: StateService,
ReadState: ReadStateService,
Tip: ChainTip + Clone + Send + Sync + 'static,
AddressBook: AddressBookPeers + Clone + Send + Sync + 'static,
BlockVerifierRouter: BlockVerifierService,
SyncStatus: ChainSyncStatus + Clone + Send + Sync + 'static,
impl<Mempool, State, ReadState, Tip, AddressBook, BlockVerifierRouter, SyncStatus> RpcImpl<Mempool, State, ReadState, Tip, AddressBook, BlockVerifierRouter, SyncStatus>where
Mempool: MempoolService,
State: StateService,
ReadState: ReadStateService,
Tip: ChainTip + Clone + Send + Sync + 'static,
AddressBook: AddressBookPeers + Clone + Send + Sync + 'static,
BlockVerifierRouter: BlockVerifierService,
SyncStatus: ChainSyncStatus + Clone + Send + Sync + 'static,
Sourcepub fn new<VersionString, UserAgentString>(
network: Network,
mining_config: Config,
debug_force_finished_sync: bool,
build_version: VersionString,
user_agent: UserAgentString,
mempool: Mempool,
state: State,
read_state: ReadState,
block_verifier_router: BlockVerifierRouter,
sync_status: SyncStatus,
latest_chain_tip: Tip,
address_book: AddressBook,
last_warn_error_log_rx: LoggedLastEvent,
mined_block_sender: Option<Sender<(Hash, Height)>>,
) -> (Self, JoinHandle<()>)
pub fn new<VersionString, UserAgentString>( network: Network, mining_config: Config, debug_force_finished_sync: bool, build_version: VersionString, user_agent: UserAgentString, mempool: Mempool, state: State, read_state: ReadState, block_verifier_router: BlockVerifierRouter, sync_status: SyncStatus, latest_chain_tip: Tip, address_book: AddressBook, last_warn_error_log_rx: LoggedLastEvent, mined_block_sender: Option<Sender<(Hash, Height)>>, ) -> (Self, JoinHandle<()>)
Create a new instance of the RPC handler.