pub type AddressStrings = GetAddressBalanceRequest;👎Deprecated: Use
GetAddressBalanceRequest instead.Expand description
A request to get the transparent balance of a set of addresses.
Aliased Type
pub struct AddressStrings {
addresses: Vec<String>,
}Fields
addresses: Vec<String>A list of transparent address strings.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 24 bytes