Hash

Type Alias Hash 

pub type Hash = GetBlockHashResponse;
A block hash used by this crate that encodes as hex by default.

Aliased Type

pub struct Hash(pub(crate) Hash);

Tuple Fields

0: Hash

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes