LoggedLastEvent

Type Alias LoggedLastEvent 

pub type LoggedLastEvent = Receiver<Option<(String, Level, DateTime<Utc>)>>;
A type alias for the last event logged by the server.

Aliased Type

pub struct LoggedLastEvent { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 16 bytes