pub struct BlockHeaderObject {Show 15 fields
hash: Hash,
confirmations: i64,
height: Height,
version: u32,
merkle_root: Root,
block_commitments: [u8; 32],
final_sapling_root: [u8; 32],
sapling_tree_size: u64,
time: i64,
nonce: [u8; 32],
solution: Solution,
bits: CompactDifficulty,
difficulty: f64,
previous_block_hash: Hash,
next_block_hash: Option<Hash>,
}Expand description
Verbose response to a getblockheader RPC request.
See the notes for the RpcServer::get_block_header method.
Fields
hash: HashThe hash of the requested block.
confirmations: i64The number of confirmations of this block in the best chain, or -1 if it is not in the best chain.
height: HeightThe height of the requested block.
version: u32The version field of the requested block.
merkle_root: RootThe merkle root of the requesteed block.
block_commitments: [u8; 32]The blockcommitments field of the requested block. Its interpretation changes depending on the network and height.
final_sapling_root: [u8; 32]The root of the Sapling commitment tree after applying this block.
sapling_tree_size: u64The number of Sapling notes in the Sapling note commitment tree
after applying this block. Used by the getblock RPC method.
time: i64The block time of the requested block header in non-leap seconds since Jan 1 1970 GMT.
nonce: [u8; 32]The nonce of the requested block header.
solution: SolutionThe Equihash solution in the requested block header.
bits: CompactDifficultyThe difficulty threshold of the requested block header displayed in compact form.
difficulty: f64Floating point number that represents the difficulty limit for this block as a multiple of the minimum difficulty for the network.
previous_block_hash: HashThe previous block hash of the requested block header.
next_block_hash: Option<Hash>The next block hash after the requested block header.
Implementations
Sourceimpl BlockHeaderObject
Auto-generated by derive_getters::Getters.
impl BlockHeaderObject
Auto-generated by derive_getters::Getters.
Sourcepub fn confirmations(&self) -> i64
pub fn confirmations(&self) -> i64
The number of confirmations of this block in the best chain, or -1 if it is not in the best chain.
Sourcepub fn merkle_root(&self) -> Root
pub fn merkle_root(&self) -> Root
The merkle root of the requesteed block.
Sourcepub fn block_commitments(&self) -> [u8; 32]
pub fn block_commitments(&self) -> [u8; 32]
The blockcommitments field of the requested block. Its interpretation changes depending on the network and height.
Sourcepub fn final_sapling_root(&self) -> [u8; 32]
pub fn final_sapling_root(&self) -> [u8; 32]
The root of the Sapling commitment tree after applying this block.
Sourcepub fn sapling_tree_size(&self) -> u64
pub fn sapling_tree_size(&self) -> u64
The number of Sapling notes in the Sapling note commitment tree
after applying this block. Used by the getblock RPC method.
Sourcepub fn time(&self) -> i64
pub fn time(&self) -> i64
The block time of the requested block header in non-leap seconds since Jan 1 1970 GMT.
Sourcepub fn bits(&self) -> CompactDifficulty
pub fn bits(&self) -> CompactDifficulty
The difficulty threshold of the requested block header displayed in compact form.
Sourcepub fn difficulty(&self) -> f64
pub fn difficulty(&self) -> f64
Floating point number that represents the difficulty limit for this block as a multiple of the minimum difficulty for the network.
Sourcepub fn previous_block_hash(&self) -> Hash
pub fn previous_block_hash(&self) -> Hash
The previous block hash of the requested block header.
Sourcepub fn next_block_hash(&self) -> Option<Hash>
pub fn next_block_hash(&self) -> Option<Hash>
The next block hash after the requested block header.
Sourceimpl BlockHeaderObject
impl BlockHeaderObject
Sourcepub fn new(
hash: Hash,
confirmations: i64,
height: Height,
version: u32,
merkle_root: Root,
block_commitments: [u8; 32],
final_sapling_root: [u8; 32],
sapling_tree_size: u64,
time: i64,
nonce: [u8; 32],
solution: Solution,
bits: CompactDifficulty,
difficulty: f64,
previous_block_hash: Hash,
next_block_hash: Option<Hash>,
) -> Self
pub fn new( hash: Hash, confirmations: i64, height: Height, version: u32, merkle_root: Root, block_commitments: [u8; 32], final_sapling_root: [u8; 32], sapling_tree_size: u64, time: i64, nonce: [u8; 32], solution: Solution, bits: CompactDifficulty, difficulty: f64, previous_block_hash: Hash, next_block_hash: Option<Hash>, ) -> Self
Constructs a new BlockHeaderObject.